@@ -3,10 +3,10 @@ estat_stats_data_id <- function(statsDataId) {
     statsDataId
   } else {
     # when statsDataId is url
-    statsDataId <- statsDataId %>%
-      stringr::str_extract("(?<=\\?)[^\\?]+") %>%
-      stringr::str_split("&") %>%
-      dplyr::first() %>%
+    statsDataId <- statsDataId |>
+      stringr::str_extract("(?<=\\?)[^\\?]+") |>
+      stringr::str_split("&") |>
+      dplyr::first() |>
       stringr::str_match("(.+)=(.+)")
 
     nms <- statsDataId[, 2L]
@@ -19,30 +19,28 @@ estat_stats_data_id <- function(statsDataId) {
 }
 
 estat_get <- function(path, setup) {
-  out <- httr::GET(setup$url,
-                   config = httr::add_headers(`Accept-Encoding` = "gzip"),
-                   path = c(setup$path, path),
-                   query = setup$query)
-  httr::stop_for_status(out)
-  httr::content(out)
+  get_content(setup$url,
+              config = httr::add_headers(`Accept-Encoding` = "gzip"),
+              path = c(setup$path, path),
+              query = setup$query)
 }
 
-#' Get meta-information of 'e-Stat' data
+#' Access 'e-Stat' data
 #'
-#' The \code{estat} gets the meta-information of a statistical table by using \code{getMetaInfo} of the 'e-Stat' API,
-#' and returns an \code{estat} object that allows editing of meta-information by \code{filter} and \code{select}.
+#' The `estat()` gets the meta-information of a statistical table by using `getMetaInfo` of the 'e-Stat' API,
+#' and returns an `estat` object that allows editing of meta-information by `dplyr::filter()` and `dplyr::select()`.
 #'
-#' @param statsDataId A statistical data ID on 'e-Stat'.
 #' @param appId An 'appId' of 'e-Stat' API.
-#' @param lang A language, Japanese (\code{"J"}) or English (\code{"E"}).
+#' @param statsDataId A statistical data ID on 'e-Stat'.
+#' @param lang A language, Japanese (`"J"`) or English (`"E"`).
 #' @param query A list of additional queries.
 #' @param path An e-Stat API path.
 #'
-#' @return A \code{estat} object.
+#' @return A `estat` object.
 #'
 #' @examples
 #' \dontrun{
-#' estat("https://www.e-stat.go.jp/dbview?sid=0003433219")
+#' estat("Your appId", "https://www.e-stat.go.jp/dbview?sid=0003433219")
 #' }
 #'
 #' @seealso <https://www.e-stat.go.jp>
@@ -66,89 +64,84 @@ estat <- function(appId,
                 query = query)
 
   meta_info <- estat_get(path = "getMetaInfo",
-                         setup = setup) %>%
-    purrr::chuck("GET_META_INFO") %>%
-    estat_check_status() %>%
+                         setup = setup) |>
+    purrr::chuck("GET_META_INFO") |>
+    estat_check_status() |>
     purrr::chuck("METADATA_INF")
 
-  table_info <- meta_info %>%
-    purrr::chuck("TABLE_INF") %>%
-    tibble::enframe() %>%
-    dplyr::mutate(value = .data$value %>%
+  table_info <- meta_info |>
+    purrr::chuck("TABLE_INF") |>
+    tibble::enframe() |>
+    dplyr::mutate(value = .data$value |>
                     purrr::map_chr(~ {
-                      .x %>%
+                      .x |>
                         paste0(collapse = " ")
                     }))
 
-  meta_info <- tibble::tibble(meta_info = meta_info %>%
-                                purrr::chuck("CLASS_INF", "CLASS_OBJ")) %>%
-    tidyr::unnest_wider("meta_info") %>%
+  meta_info <- tibble::tibble(meta_info = meta_info |>
+                                purrr::chuck("CLASS_INF", "CLASS_OBJ")) |>
+    tidyr::unnest_wider("meta_info") |>
     dplyr::rename_with(~ {
-      .x %>%
+      .x |>
         stringr::str_remove("^@")
-    }) %>%
+    }) |>
     dplyr::rename(key = "id",
                   key_name = "name",
-                  value = "CLASS") %>%
-    dplyr::mutate(value = .data$value %>%
+                  value = "CLASS") |>
+    dplyr::mutate(value = .data$value |>
                     purrr::modify(~ {
-                      .x %>%
-                        dplyr::bind_rows() %>%
+                      .x |>
+                        dplyr::bind_rows() |>
                         dplyr::rename_with(~ {
-                          .x %>%
+                          .x |>
                             stringr::str_remove("^@")
-                        }) %>%
-                        tibble::rowid_to_column(".estat_rowid") %>%
-                        new_data_frame(class = c("tbl_estat", "tbl"))
+                        }) |>
+                        tibble::rowid_to_column(".estat_rowid") |>
+                        stickyr::new_sticky_tibble(cols = ".estat_rowid",
+                                                   col_show = !".estat_rowid",
+                                                   class = "tbl_estat")
                     }),
-                  codes = .data$value %>%
+                  codes = .data$value |>
                     purrr::modify(~ .x$code),
-                  width_key_name = .data$key_name %>%
-                    stringi::stri_width() %>%
-                    max())
+                  width_key_name = .data$key_name |>
+                    pillar::get_max_extent())
 
-  navigatr::new_menu(key = meta_info$key,
-                     value = meta_info$value,
-                     attrs = meta_info[c("key_name", "width_key_name")],
+  navigatr::new_nav_menu(key = meta_info$key,
+                         value = meta_info$value,
+                         attrs = meta_info[c("key_name", "width_key_name")],
 
-                     setup = setup,
-                     query_name = meta_info$key,
-                     codes = meta_info$codes,
-                     table_info = table_info,
+                         setup = setup,
+                         query_name = meta_info$key,
+                         codes = meta_info$codes,
+                         table_info = table_info,
 
-                     class = "estat")
+                         class = "estat")
 }
 
 estat_check_status <- function(x) {
   if (x$RESULT$STATUS != 0) {
-    stop(x$RESULT$ERROR_MSG)
+    abort(x$RESULT$ERROR_MSG)
   }
   x
 }
 
-#' Get table information for 'e-Stat' data
-#'
-#' @param x A \code{estat} object.
-#'
-#' @return A \code{tbl} of the table information.
-#'
 #' @export
-estat_table_info <- function(x) {
-  attr(x, "table_info")
+summary.estat <- function(object, ...) {
+  attr(object, "table_info")
 }
 
 #' @export
-select.tbl_estat <- function(.data, ...) {
-  out <- NextMethod()
-  dplyr::bind_cols(.estat_rowid = .data$.estat_rowid,
-                   out[setdiff(names(out), ".estat_rowid")])
+summary.tbl_estat <- function(object, ...) {
+  object |>
+    deactivate() |>
+    summary()
 }
 
 #' @export
 collect.estat <- function(x,
                           n = "n",
-                          sep = "_",
-                          query = NULL,
+                          names_sep = "_",
+                          query = list(),
                           limit = 1e5, ...) {
   setup <- attr(x, "setup")
   setup$query <- estat_query(x, query)
@@ -163,7 +156,8 @@ collect.estat <- function(x,
     data <- tibble::new_tibble(data)
   } else {
     start <- seq(1, total, limit)
-    pb <- progress::progress_bar$new(total = vctrs::vec_size(start))
+    pb <- progress::progress_bar$new(format = format_downloading,
+                                     total = vctrs::vec_size(start))
     data <- purrr::map_dfr(start,
                            function(start) {
                              out <- estat_collect(setup = setup,
@@ -175,39 +169,40 @@ collect.estat <- function(x,
                            })
   }
 
-  cols <- list(x$key, x$value, query_name, attr(x, "codes")) %>%
+  cols <- list(x$key, x$value, query_name, attr(x, "codes")) |>
     purrr::pmap(function(key, value, query_name, codes) {
-      value %>%
+      value |>
+        tibble::as_tibble() |>
         dplyr::rename_with(~ {
           paste(key, .x,
-                sep = sep)
+                sep = names_sep)
         },
-        !".estat_rowid") %>%
+        !".estat_rowid") |>
         dplyr::mutate(!!query_name := codes[.data$.estat_rowid],
                       .keep = "unused")
     })
 
   for (i in vec_seq_along(query_name)) {
-    data <- data %>%
+    data <- data |>
       dplyr::left_join(cols[[i]],
-                       by = query_name[[i]]) %>%
+                       by = query_name[[i]]) |>
       dplyr::select(!dplyr::all_of(query_name[[i]]))
   }
 
-  data %>%
+  data |>
     dplyr::relocate(!dplyr::all_of(n))
 }
 
 #' @export
 collect.tbl_estat <- function(x, ...) {
-  x %>%
-    deactivate() %>%
-    collect(...)
+  x |>
+    deactivate() |>
+    collect.estat(...)
 }
 
 estat_query <- function(x, query) {
-  query_name <- x %>%
-    attr("query_name") %>%
+  query_name <- x |>
+    attr("query_name") |>
     stringr::str_to_sentence()
   query_name <- paste0("cd", query_name)
 
@@ -235,9 +230,9 @@ estat_total <- function(setup) {
                    list(cntGetFlg = "Y"))
 
   total <- estat_get(path = "getStatsData",
-                     setup = setup) %>%
-    purrr::chuck("GET_STATS_DATA") %>%
-    estat_check_status() %>%
+                     setup = setup) |>
+    purrr::chuck("GET_STATS_DATA") |>
+    estat_check_status() |>
     purrr::chuck("STATISTICAL_DATA", "RESULT_INF", "TOTAL_NUMBER")
 
   print(stringr::str_glue("The total number of data is {total}."))
@@ -251,20 +246,19 @@ estat_collect <- function(setup, start, limit, n) {
                                limit = format(limit,
                                               scientific = FALSE))
   estat_get(path = "getStatsData",
-            setup = setup) %>%
-    purrr::chuck("GET_STATS_DATA") %>%
-    estat_check_status() %>%
-    purrr::chuck("STATISTICAL_DATA", "DATA_INF", "VALUE") %>%
-    dplyr::bind_rows() %>%
-    dplyr::rename_with(~ .x %>%
-                         stringr::str_remove("^@")) %>%
-    dplyr::rename(!!n := "$") %>%
+            setup = setup) |>
+    purrr::chuck("GET_STATS_DATA") |>
+    estat_check_status() |>
+    purrr::chuck("STATISTICAL_DATA", "DATA_INF", "VALUE") |>
+    dplyr::bind_rows() |>
+    dplyr::rename_with(~ .x |>
+                         stringr::str_remove("^@")) |>
+    dplyr::rename(!!n := "$") |>
     dplyr::select(!dplyr::any_of("unit"))
 }
 
 # printing ----------------------------------------------------------------
 
-#' @importFrom pillar obj_sum
 #' @export
 obj_sum.tbl_estat <- function(x) {
   attrs <- attributes(x)
@@ -273,9 +267,3 @@ obj_sum.tbl_estat <- function(x) {
          "[", big_mark(vec_size(x)), "] ",
          "<", commas(nms), ">")
 }
-
-#' @export
-format.tbl_estat <- function(x, ...) {
-  x <- x[setdiff(names(x), ".estat_rowid")]
-  NextMethod()
-}
